%global srcname fsleyes

%global desc \
FSLeyes, the FSL image viewer

# PyPi tar does not include tests
# Upstream says the tests, since they use xvfb etc., may not always pass on all
# platforms.
%bcond_with tests


Name:           python-%{srcname}
Version:        0.27.3
Release:        1%{?dist}
Summary:        FSLeyes, the FSL image viewer

License:        ASL 2.0
URL:            https://pypi.python.org/pypi/%{srcname}
Source0:        %pypi_source

BuildArch:      noarch

%description
%{desc}

%package -n python3-%{srcname}
Summary:        %{summary}
BuildRequires:  python3-devel
BuildRequires:  graphviz
BuildRequires:  %{py3_dist sphinx}
BuildRequires:  %{py3_dist sphinx_rtd_theme}
BuildRequires:  %{py3_dist mock}
BuildRequires:  %{py3_dist pytest}
BuildRequires:  %{py3_dist pytest-cov}
BuildRequires:  %{py3_dist wxpython}
BuildRequires:  freeglut-devel
BuildRequires:  xorg-x11-server-Xvfb

Requires:       %{py3_dist setuptools}
Requires:       %{py3_dist six}
Requires:       %{py3_dist numpy}
Requires:       %{py3_dist matplotlib}
Requires:       %{py3_dist nibabel} > 2.2.1
Requires:       %{py3_dist jinja2}
Requires:       %{py3_dist pillow}
Requires:       %{py3_dist pyopengl}
Requires:       %{py3_dist pyparsing}
Requires:       %{py3_dist scipy}
Requires:       %{py3_dist wxpython}
Requires:       %{py3_dist fslpy}
Requires:       %{py3_dist fsleyes-props}
Requires:       %{py3_dist fsleyes-widgets}
Requires:       dcm2niix
Requires:       %{py3_dist trimesh}
Requires:       %{py3_dist indexed_gzip}
# PyOpenGL-accelerate is provided by this
Requires:       %{py3_dist pyopengl}
Requires:       %{py3_dist sip}

# Not yet avaiable in Fedora
# Extra requirements, so skipping for the time being
# https://git.fmrib.ox.ac.uk/fsl/fsleyes/fsleyes/blob/master/requirements-extra.txt
# Requires:       %%{py3_dist xnat}
# Requires:       %%{py3_dist wxnatpy}
%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{srcname}
%{desc}

%package doc
Summary:        %{summary}

%description doc
This package contains documentation for %{name}.

%prep
%autosetup -n %{srcname}-%{version}
rm -rfv fsleyes_widgets.egg-info

# Remove unnecessary upper limit on Pillow:
# https://github.com/pauldmccarthy/fsleyes/issues/7
sed -i 's/\(Pillow>=3.2.0\),.*/\1/' requirements.txt

# Use system sip
sed -i 's/import wx.siplib as sip/import sip/' fsleyes/gl/__init__.py
sed -i 's/import wx.siplib as sip/import sip/' fsleyes/panel.py
sed -i 's/wx.siplib/sip/' fsleyes/gl/__init__.py
sed -i 's/wx.siplib/sip/' fsleyes/panel.py

# remove unneeded shebangs
find . -name "*py" -exec sed -i '/#!\/usr\/bin\/env python/ d' '{}' \;

%build
%py3_build

# Build documentation
%{__python3} setup.py userdoc
%{__python3} setup.py apidoc
# Remove build artefacts
pushd userdoc
    rm -frv html/.buildinfo
    rm -frv html/.doctrees
    mv html userdoc_html
popd

pushd apidoc
    rm -frv html/.buildinfo
    rm -frv html/.doctrees
    mv html apidoc_html
popd


%install
%py3_install

# remove docs installed in the python bits
rm -rfv $RPM_BUILD_ROOT/%{python3_sitelib}/%{srcname}/userdoc


%check
%if %{with tests}
export MPLBACKEND=wxagg
export FSLEYES_TEST_GL=2.1
xvfb-run -s "-screen 0 640x480x24" pytest-3
sleep 5
xvfb-run -s "-screen 0 640x480x24" pytest-3
sleep 5
xvfb-run -s "-screen 0 640x480x24" pytest-3
sleep 5

# test overlay types for GL14 as well
export FSLEYES_TEST_GL=1.4
xvfb-run -s "-screen 0 640x480x24" pytest-3
%endif

%files -n python3-%{srcname}
%license LICENSE COPYRIGHT
%doc README.rst
%{_bindir}/%{srcname}
%{_bindir}/render
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{srcname}-%{version}-py3.?.egg-info

%files doc
%license LICENSE COPYRIGHT
%doc userdoc/userdoc_html apidoc/apidoc_html

%changelog
* Sat Feb 16 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.27.3-1
- Update to latest upstream release

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.26.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Tue Nov 27 2018 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.26.4-3
- Remove unnecessary pillow version limit
- Use wxpython4 and sip correctly from system

* Mon Nov 26 2018 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.26.4-2
- Fix requires
- Enable available requires

* Fri Nov 09 2018 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 0.26.4-1
- Initial build
